@@ -5,6 +5,7 @@
 #endif
 
 #include "scripting/python/core.h"
+#include <Python.h>
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -17,6 +18,7 @@
 #include "util/file.h"
 #include "util/string.h"
 
+
 PyObject *pDict, *pModule;
 
 void
@@ -37,8 +39,12 @@ cleanup_python(struct module *module)
 void
 init_python(struct module *module)
 {
-	unsigned char *python_path = straconcat(elinks_home, ":", CONFDIR, NULL);
+	unsigned char *python_path;
 
+	if (elinks_home)
+		python_path = straconcat(elinks_home, ":", CONFDIR, NULL);
+	else
+		python_path = stracpy(CONFDIR);
 	if (!python_path) return;
 	env_set("PYTHONPATH", python_path, -1);
 	mem_free(python_path);
